import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import CheckedIcon from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_pzq7s","start":"checkbox__start_pzq7s","center":"checkbox__center_pzq7s","addons":"checkbox__addons_pzq7s","block":"checkbox__block_pzq7s","box":"checkbox__box_pzq7s","checkedIcon":"checkbox__checkedIcon_pzq7s","s":"checkbox__s_pzq7s","disabled":"checkbox__disabled_pzq7s","inactive":"checkbox__inactive_pzq7s","checked":"checkbox__checked_pzq7s","indeterminate":"checkbox__indeterminate_pzq7s","label":"checkbox__label_pzq7s","hint":"checkbox__hint_pzq7s","focused":"checkbox__focused_pzq7s","content":"checkbox__content_pzq7s","indeterminateLine":"checkbox__indeterminateLine_pzq7s"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.inactive]: inactive,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("span", { className: styles.box },
            React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId }, restProps)),
            checked && React.createElement(CheckedIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && React.createElement("span", { className: styles.hint }, hint))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
